function [q,me]=TessHyp(N,order)
% FUNCTION fc_hypermesh.CG.TessHyp: Tessallation by unit hypercubes
%     of a cartesian grid.
%
% USAGE
%   [q,me]=fc_hypermesh.CG.TessHyp(N) 
% 
% INPUT
%   N : 1-by-d array. Specify the cartesian grid [0,N(1)]x...x[0,N(d)].
%
% OUTPUT
%   q : d-by-nq array with nq=(N(1)+1)x...x(N(d)+1). 
%       Contains all the points of the cartesian grid
%   me: 2^d-by-nme array with nme=N(1)x...xN(d).
%       Connectivity array of the tessallation.
%
%    Copyright (C) 2016-2019 F. Cuvelier
% 
  if nargin==1, order=1;end
  d=length(N);
  q=fc_hypermesh.CG.points(order*N)/order;
  Hinv=order*fc_hypermesh.CG.points(N-1);
  kqhat=fc_hypermesh.CG.points(order*ones(1,d));
  beta=fc_hypermesh.CG.beta(order*N);
  ibase=beta*Hinv+1;
  nl=(order+1)^d;nme=length(ibase);
  bq=[beta*kqhat]';
  me=repmat(ibase,nl,1)+repmat(bq,1,nme);  
end

